.. image:: https://github.com/asphalt-framework/asphalt-web/actions/workflows/test.yml/badge.svg
  :target: https://github.com/asphalt-framework/asphalt-web/actions/workflows/test.yml
  :alt: Build Status
.. image:: https://coveralls.io/repos/github/asphalt-framework/asphalt-web/badge.svg?branch=master
  :target: https://coveralls.io/github/asphalt-framework/asphalt-web?branch=master
  :alt: Code Coverage
.. image:: https://readthedocs.org/projects/asphalt-web/badge/?version=latest
  :target: https://asphalt-web.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation

This Asphalt framework component provides integrations for various web frameworks,
enabling them to make use of Asphalt components.

The following web frameworks are catered for:

* ASGI_ 3.0
* AIOHTTP_
* Django_
* FastAPI_
* Starlette_

WSGI is not supported because Asphalt focuses on asynchronous operation and WSGI is a
synchronous web application gateway standard.

.. _ASGI: https://asgi.readthedocs.io/
.. _AIOHTTP: https://docs.aiohttp.org/
.. _Django: https://www.djangoproject.com/
.. _FastAPI: https://fastapi.tiangolo.com/
.. _Starlette: https://www.starlette.io/

Project links
-------------

* `Documentation <http://asphalt-web.readthedocs.org/en/latest/>`_
* `Help and support <https://github.com/asphalt-framework/asphalt/wiki/Help-and-support>`_
* `Source code <https://github.com/asphalt-framework/asphalt-web>`_
* `Issue tracker <https://github.com/asphalt-framework/asphalt-web/issues>`_
